@@ -97,7 +97,7 @@ pub struct TracingMutex<T> {
 #[derive(Debug)]
 pub struct TracingMutexGuard<'a, T> {
     inner: MutexGuard<'a, T>,
-    mutex: BorrowedMutex<'a>,
+    _mutex: BorrowedMutex<'a>,
 }
 
 fn map_lockresult<T, I, F>(result: LockResult<I>, mapper: F) -> LockResult<T>
@@ -144,7 +144,7 @@ impl<T> TracingMutex<T> {
         let result = self.inner.lock();
 
         let mapper = |guard| TracingMutexGuard {
-            mutex,
+            _mutex: mutex,
             inner: guard,
         };
 
@@ -163,7 +163,7 @@ impl<T> TracingMutex<T> {
         let result = self.inner.try_lock();
 
         let mapper = |guard| TracingMutexGuard {
-            mutex,
+            _mutex: mutex,
             inner: guard,
         };
 
@@ -195,7 +195,7 @@ impl<T> From<T> for TracingMutex<T> {
 }
 
 impl<'a, T> Deref for TracingMutexGuard<'a, T> {
-    type Target = MutexGuard<'a, T>;
+    type Target = T;
 
     fn deref(&self) -> &Self::Target {
         &self.inner
@@ -227,7 +227,7 @@ pub struct TracingRwLock<T> {
 #[derive(Debug)]
 pub struct TracingRwLockGuard<'a, L> {
     inner: L,
-    mutex: BorrowedMutex<'a>,
+    _mutex: BorrowedMutex<'a>,
 }
 
 /// Wrapper around [`std::sync::RwLockReadGuard`].
@@ -254,7 +254,10 @@ impl<T> TracingRwLock<T> {
         let mutex = self.id.get_borrowed();
         let result = self.inner.read();
 
-        map_lockresult(result, |inner| TracingRwLockGuard { inner, mutex })
+        map_lockresult(result, |inner| TracingRwLockGuard {
+            inner,
+            _mutex: mutex,
+        })
     }
 
     /// Wrapper for [`std::sync::RwLock::write`].
@@ -268,7 +271,10 @@ impl<T> TracingRwLock<T> {
         let mutex = self.id.get_borrowed();
         let result = self.inner.write();
 
-        map_lockresult(result, |inner| TracingRwLockGuard { inner, mutex })
+        map_lockresult(result, |inner| TracingRwLockGuard {
+            inner,
+            _mutex: mutex,
+        })
     }
 
     /// Wrapper for [`std::sync::RwLock::try_read`].
@@ -282,7 +288,10 @@ impl<T> TracingRwLock<T> {
         let mutex = self.id.get_borrowed();
         let result = self.inner.try_read();
 
-        map_trylockresult(result, |inner| TracingRwLockGuard { inner, mutex })
+        map_trylockresult(result, |inner| TracingRwLockGuard {
+            inner,
+            _mutex: mutex,
+        })
     }
 
     /// Wrapper for [`std::sync::RwLock::try_write`].
@@ -296,7 +305,10 @@ impl<T> TracingRwLock<T> {
         let mutex = self.id.get_borrowed();
         let result = self.inner.try_write();
 
-        map_trylockresult(result, |inner| TracingRwLockGuard { inner, mutex })
+        map_trylockresult(result, |inner| TracingRwLockGuard {
+            inner,
+            _mutex: mutex,
+        })
     }
 
     /// Return a mutable reference to the underlying data.
@@ -401,7 +413,12 @@ mod tests {
 
     #[test]
     fn test_mutex_usage() {
-        let mutex = Arc::new(TracingMutex::new(()));
+        let mutex = Arc::new(TracingMutex::new(0));
+
+        assert_eq!(*mutex.lock().unwrap(), 0);
+        *mutex.lock().unwrap() = 1;
+        assert_eq!(*mutex.lock().unwrap(), 1);
+
         let mutex_clone = mutex.clone();
 
         let _guard = mutex.lock().unwrap();
@@ -418,7 +435,14 @@ mod tests {
 
     #[test]
     fn test_rwlock_usage() {
-        let rwlock = Arc::new(TracingRwLock::new(()));
+        let rwlock = Arc::new(TracingRwLock::new(0));
+
+        assert_eq!(*rwlock.read().unwrap(), 0);
+        assert_eq!(*rwlock.write().unwrap(), 0);
+        *rwlock.write().unwrap() = 1;
+        assert_eq!(*rwlock.read().unwrap(), 1);
+        assert_eq!(*rwlock.write().unwrap(), 1);
+
         let rwlock_clone = rwlock.clone();
 
         let _read_lock = rwlock.read().unwrap();
